﻿function Copy-FileWithBackup {
    Param(
        [String] $SourcePath,
        [String] $DestinationPath,
        [String] $Filename,
        [Switch] $SaveCopy
    )
    if (!(Test-Path $SourcePath))
     {
        throw "File $SourcePath does not exist"
    }
    $sourceFilePath = [System.IO.Path]::Combine($SourcePath, $Filename)
    $DestinationFilePath = [System.IO.Path]::Combine($DestinationPath, $Filename)
    $extension = (Get-Item $sourceFilePath).Extension
    $basename = (Get-Item $sourceFilePath).BaseName
    $SaveCopyFilePath = [System.IO.Path]::Combine($DestinationPath, "${basename}_$(Get-Date -Format 'yyyyMMddHHmmss')$extension");

    if ($SaveCopy.IsPresent) {
        Move-Item -Path $DestinationFilePath -Destination $SaveCopyFilePath
    }

    Copy-Item -Path $sourceFilePath -Destination $DestinationPath
}

function Copy-FileWithConfirmation {
    Param(
        [String] $SourcePath,
        [String] $DestinationPath,
        [String] $Filename,
        [Switch] $SaveCopy
    )

    $reply = 
        [System.Windows.MessageBox]::Show(
            "Do you really want to overwrite the file ${Filename} in ${DestinationPath}?", 
            "Copy ${Filename}", 
            [System.Windows.MessageBoxButton]::OKCancel, 
            [System.Windows.MessageBoxImage]::Question) 
    if  ($reply -eq [System.Windows.MessageBoxResult]::OK) { 
        Copy-FileWithBackup -SourcePath $SourcePath -DestinationPath $DestinationPath -Filename $Filename -SaveCopy:$($SaveCopy.IsPresent)
    }
}
# SIG # Begin signature block
# MIIn7wYJKoZIhvcNAQcCoIIn4DCCJ9wCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCAMPe1/5CTC9zof
# rILMRBy+hWM5GaTeRLRurKHMhPhaP6CCIFwwggWDMIIDa6ADAgECAg5F5rsDgzPD
# hWVI5v9FUTANBgkqhkiG9w0BAQwFADBMMSAwHgYDVQQLExdHbG9iYWxTaWduIFJv
# b3QgQ0EgLSBSNjETMBEGA1UEChMKR2xvYmFsU2lnbjETMBEGA1UEAxMKR2xvYmFs
# U2lnbjAeFw0xNDEyMTAwMDAwMDBaFw0zNDEyMTAwMDAwMDBaMEwxIDAeBgNVBAsT
# F0dsb2JhbFNpZ24gUm9vdCBDQSAtIFI2MRMwEQYDVQQKEwpHbG9iYWxTaWduMRMw
# EQYDVQQDEwpHbG9iYWxTaWduMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKC
# AgEAlQfoc8pm+ewUyns89w0I8bRFCyyCtEjG61s8roO4QZIzFKRvf+kqzMawiGvF
# tonRxrL/FM5RFCHsSt0bWsbWh+5NOhUG7WRmC5KAykTec5RO86eJf094YwjIElBt
# QmYvTbl5KE1SGooagLcZgQ5+xIq8ZEwhHENo1z08isWyZtWQmrcxBsW+4m0yBqYe
# +bnrqqO4v76CY1DQ8BiJ3+QPefXqoh8q0nAue+e8k7ttU+JIfIwQBzj/ZrJ3YX7g
# 6ow8qrSk9vOVShIHbf2MsonP0KBhd8hYdLDUIzr3XTrKotudCd5dRC2Q8YHNV5L6
# frxQBGM032uTGL5rNrI55KwkNrfw77YcE1eTtt6y+OKFt3OiuDWqRfLgnTahb1SK
# 8XJWbi6IxVFCRBWU7qPFOJabTk5aC0fzBjZJdzC8cTflpuwhCHX85mEWP3fV2ZGX
# hAps1AJNdMAU7f05+4PyXhShBLAL6f7uj+FuC7IIs2FmCWqxBjplllnA8DX9ydoo
# jRoRh3CBCqiadR2eOoYFAJ7bgNYl+dwFnidZTHY5W+r5paHYgw/R/98wEfmFzzNI
# 9cptZBQselhP00sIScWVZBpjDnk99bOMylitnEJFeW4OhxlcVLFltr+Mm9wT6Q1v
# uC7cZ27JixG1hBSKABlwg3mRl5HUGie/Nx4yB9gUYzwoTK8CAwEAAaNjMGEwDgYD
# VR0PAQH/BAQDAgEGMA8GA1UdEwEB/wQFMAMBAf8wHQYDVR0OBBYEFK5sBaOTE+Ki
# 5+LXHNbH8H/IZ1OgMB8GA1UdIwQYMBaAFK5sBaOTE+Ki5+LXHNbH8H/IZ1OgMA0G
# CSqGSIb3DQEBDAUAA4ICAQCDJe3o0f2VUs2ewASgkWnmXNCE3tytok/oR3jWZZip
# W6g8h3wCitFutxZz5l/AVJjVdL7BzeIRka0jGD3d4XJElrSVXsB7jpl4FkMTVlez
# orM7tXfcQHKso+ubNT6xCCGh58RDN3kyvrXnnCxMvEMpmY4w06wh4OMd+tgHM3ZU
# ACIquU0gLnBo2uVT/INc053y/0QMRGby0uO9RgAabQK6JV2NoTFR3VRGHE3bmZbv
# GhwEXKYV73jgef5d2z6qTFX9mhWpb+Gm+99wMOnD7kJG7cKTBYn6fWN7P9BxgXwA
# 6JiuDng0wyX7rwqfIGvdOxOPEoziQRpIenOgd2nHtlx/gsge/lgbKCuobK1ebcAF
# 0nu364D+JTf+AptorEJdw+71zNzwUHXSNmmc5nsE324GabbeCglIWYfrexRgemSq
# aUPvkcdM7BjdbO9TLYyZ4V7ycj7PVMi9Z+ykD0xF/9O5MCMHTI8Qv4aW2ZlatJlX
# HKTMuxWJU7osBQ/kxJ4ZsRg01Uyduu33H68klQR4qAO77oHl2l98i0qhkHQlp7M+
# S8gsVr3HyO844lyS8Hn3nIS6dC1hASB+ftHyTwdZX4stQ1LrRgyU4fVmR3l31VRb
# H60kN8tFWk6gREjI2LCZxRWECfbWSUnAZbjmGnFuoKjxguhFPmzWAtcKZ4MFWsmk
# EDCCBlkwggRBoAMCAQICDQHsHJJA3v0uQF18R3QwDQYJKoZIhvcNAQEMBQAwTDEg
# MB4GA1UECxMXR2xvYmFsU2lnbiBSb290IENBIC0gUjYxEzARBgNVBAoTCkdsb2Jh
# bFNpZ24xEzARBgNVBAMTCkdsb2JhbFNpZ24wHhcNMTgwNjIwMDAwMDAwWhcNMzQx
# MjEwMDAwMDAwWjBbMQswCQYDVQQGEwJCRTEZMBcGA1UEChMQR2xvYmFsU2lnbiBu
# di1zYTExMC8GA1UEAxMoR2xvYmFsU2lnbiBUaW1lc3RhbXBpbmcgQ0EgLSBTSEEz
# ODQgLSBHNDCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAPAC4jAj+uAb
# 4Zp0s691g1+pR1LHYTpjfDkjeW10/DHkdBIZlvrOJ2JbrgeKJ+5Xo8Q17bM0x6zD
# DOuAZm3RKErBLLu5cPJyroz3mVpddq6/RKh8QSSOj7rFT/82QaunLf14TkOI/pMZ
# F9nuMc+8ijtuasSI8O6X9tzzGKBLmRwOh6cm4YjJoOWZ4p70nEw/XVvstu/SZc9F
# C1Q9sVRTB4uZbrhUmYqoMZI78np9/A5Y34Fq4bBsHmWCKtQhx5T+QpY78Quxf39G
# mA6HPXpl69FWqS69+1g9tYX6U5lNW3TtckuiDYI3GQzQq+pawe8P1Zm5P/RPNfGc
# D9M3E1LZJTTtlu/4Z+oIvo9Jev+QsdT3KRXX+Q1d1odDHnTEcCi0gHu9Kpu7hOEO
# rG8NubX2bVb+ih0JPiQOZybH/LINoJSwspTMe+Zn/qZYstTYQRLBVf1ukcW7sUwI
# S57UQgZvGxjVNupkrs799QXm4mbQDgUhrLERBiMZ5PsFNETqCK6dSWcRi4LlrVqG
# p2b9MwMB3pkl+XFu6ZxdAkxgPM8CjwH9cu6S8acS3kISTeypJuV3AqwOVwwJ0WGe
# Joj8yLJN22TwRZ+6wT9Uo9h2ApVsao3KIlz2DATjKfpLsBzTN3SE2R1mqzRzjx59
# fF6W1j0ZsJfqjFCRba9Xhn4QNx1rGhTfAgMBAAGjggEpMIIBJTAOBgNVHQ8BAf8E
# BAMCAYYwEgYDVR0TAQH/BAgwBgEB/wIBADAdBgNVHQ4EFgQU6hbGaefjy1dFOTOk
# 8EC+0MO9ZZYwHwYDVR0jBBgwFoAUrmwFo5MT4qLn4tcc1sfwf8hnU6AwPgYIKwYB
# BQUHAQEEMjAwMC4GCCsGAQUFBzABhiJodHRwOi8vb2NzcDIuZ2xvYmFsc2lnbi5j
# b20vcm9vdHI2MDYGA1UdHwQvMC0wK6ApoCeGJWh0dHA6Ly9jcmwuZ2xvYmFsc2ln
# bi5jb20vcm9vdC1yNi5jcmwwRwYDVR0gBEAwPjA8BgRVHSAAMDQwMgYIKwYBBQUH
# AgEWJmh0dHBzOi8vd3d3Lmdsb2JhbHNpZ24uY29tL3JlcG9zaXRvcnkvMA0GCSqG
# SIb3DQEBDAUAA4ICAQB/4ojZV2crQl+BpwkLusS7KBhW1ky/2xsHcMb7CwmtADpg
# Mx85xhZrGUBJJQge5Jv31qQNjx6W8oaiF95Bv0/hvKvN7sAjjMaF/ksVJPkYROwf
# wqSs0LLP7MJWZR29f/begsi3n2HTtUZImJcCZ3oWlUrbYsbQswLMNEhFVd3s6Uqf
# XhTtchBxdnDSD5bz6jdXlJEYr9yNmTgZWMKpoX6ibhUm6rT5fyrn50hkaS/SmqFy
# 9vckS3RafXKGNbMCVx+LnPy7rEze+t5TTIP9ErG2SVVPdZ2sb0rILmq5yojDEjBO
# sghzn16h1pnO6X1LlizMFmsYzeRZN4YJLOJF1rLNboJ1pdqNHrdbL4guPX3x8pEw
# BZzOe3ygxayvUQbwEccdMMVRVmDofJU9IuPVCiRTJ5eA+kiJJyx54jzlmx7jqoSC
# iT7ASvUh/mIQ7R0w/PbM6kgnfIt1Qn9ry/Ola5UfBFg0ContglDk0Xuoyea+SKor
# VdmNtyUgDhtRoNRjqoPqbHJhSsn6Q8TGV8Wdtjywi7C5HDHvve8U2BRAbCAdwi3o
# C8aNbYy2ce1SIf4+9p+fORqurNIveiCx9KyqHeItFJ36lmodxjzK89kcv1NNpEdZ
# fJXEQ0H5JeIsEH6B+Q2Up33ytQn12GByQFCVINRDRL76oJXnIFm2eMakaqoimzCC
# BmgwggRQoAMCAQICEAFIkD3CirynoRlNDBxXuCkwDQYJKoZIhvcNAQELBQAwWzEL
# MAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNpZ24gbnYtc2ExMTAvBgNVBAMT
# KEdsb2JhbFNpZ24gVGltZXN0YW1waW5nIENBIC0gU0hBMzg0IC0gRzQwHhcNMjIw
# NDA2MDc0MTU4WhcNMzMwNTA4MDc0MTU4WjBjMQswCQYDVQQGEwJCRTEZMBcGA1UE
# CgwQR2xvYmFsU2lnbiBudi1zYTE5MDcGA1UEAwwwR2xvYmFsc2lnbiBUU0EgZm9y
# IE1TIEF1dGhlbnRpY29kZSBBZHZhbmNlZCAtIEc0MIIBojANBgkqhkiG9w0BAQEF
# AAOCAY8AMIIBigKCAYEAwsncA7YbUPoqDeicpCHbKKcd9YC1EnQj/l4vwxpdlrIg
# GRlQX3YjJjXGIeyU77WiOsWQgZsh7wsnpOMXZDvak9RWLzzXWPltrMAvkHgjScD4
# wY9wE9Rr3yaIWnZ7SPfhpKbvCxrzJVQPgJ4jEhIT0bD3AuMrDf9APgBCQ94a70z0
# h6nynjzQBufiY9LrTFvdXViU0+WlOSiqB152IzD8/H+YDcVlbRvVdEU6RrCiFnXe
# osIqcHy2drzZG666XZz2h5XOqqjitaOxk25ApZsQiHYWTjSh/J7x4RpU0cgkV5R2
# rcLH7KOjlnXixihrAgXoS7m14FIreAGMKjEsTOgF5W+fD4QmLmhs+stNGXwYwf9q
# GqnLvqN1+OnIGLLM3S9BQCAcz4gLF8mwikPL4muTUfERvkK8+FHy2gACvggYKAUn
# xNw7XXcpHhnUQSpmfbRSc1xCpZDTjcWjqjfOcwGUJBlCQ9GUj0t+3cttvBtOe/mq
# CyJLSYBJcBstT940YD69AgMBAAGjggGeMIIBmjAOBgNVHQ8BAf8EBAMCB4AwFgYD
# VR0lAQH/BAwwCgYIKwYBBQUHAwgwHQYDVR0OBBYEFFtre/RwdAjBDSrI7/HEuUDS
# Ssb9MEwGA1UdIARFMEMwQQYJKwYBBAGgMgEeMDQwMgYIKwYBBQUHAgEWJmh0dHBz
# Oi8vd3d3Lmdsb2JhbHNpZ24uY29tL3JlcG9zaXRvcnkvMAwGA1UdEwEB/wQCMAAw
# gZAGCCsGAQUFBwEBBIGDMIGAMDkGCCsGAQUFBzABhi1odHRwOi8vb2NzcC5nbG9i
# YWxzaWduLmNvbS9jYS9nc3RzYWNhc2hhMzg0ZzQwQwYIKwYBBQUHMAKGN2h0dHA6
# Ly9zZWN1cmUuZ2xvYmFsc2lnbi5jb20vY2FjZXJ0L2dzdHNhY2FzaGEzODRnNC5j
# cnQwHwYDVR0jBBgwFoAU6hbGaefjy1dFOTOk8EC+0MO9ZZYwQQYDVR0fBDowODA2
# oDSgMoYwaHR0cDovL2NybC5nbG9iYWxzaWduLmNvbS9jYS9nc3RzYWNhc2hhMzg0
# ZzQuY3JsMA0GCSqGSIb3DQEBCwUAA4ICAQAuaz6Pf7CwYNnxnYTclbbfXw2/JFHj
# GgaqVQTLYcHvZXGuC/2UJFcAx+T2DLwYlX0vGWpgM6a+0AhVVgS24/4eu+UQdlQ7
# q1whXio1TUbLpky6BEBgYCzb0/ad3soyEAx4sLtWxQdLcLynD6tyvI3L6+7BTGvZ
# +pihdD7pqMh5fHZ3SP3P4/ANwenDkuAHDBMvP2t/NdnVt+5vfFjA8T8MGbICo0lM
# nATD8LSXp+BNaiW6NBZiZsh4vGlzql9yojVYHibrvzIUqhJ66/SWa39yrOqnOQgz
# ATY+YSR+EZ0RHnYiVONAuy6GDHaeadLEHD2iC4yIBANU3ukbF/4sK57Z1lsiOPxk
# QIbNF3/hqZ+5v5JBqG8mavQPKLBAkZAvTrZ2ULxNI9l/T2uTKads59AwPqmTH8JQ
# KznFsvhNJyTR/XbYvvmT9KlUCtV2WNE8nuoa6CTE+zbxL1nTksPsy2BSHhxGJQj/
# ftmTrhSVqIaKBy5Ui3NMNxU4UFaH8U+uHI/JoWwvC/y7HG8tvaq262gj8O2UJxRj
# y6z0Z4osgdMUEhgBP4R6ruxHYD9oWJnJSsKhmRUFwq3eou/Xp1V8vIQbTZS7jkqF
# RNmBPaqjJVVfpGvNNmwA+f9y3lrs/8mgQZYaQGqFkRyvdWOoy1oztZQzfrKND3O+
# h/yvOnMfeyDbcjCCBrAwggSYoAMCAQICEAitQLJg0pxMn17Nqb2TrtkwDQYJKoZI
# hvcNAQEMBQAwYjELMAkGA1UEBhMCVVMxFTATBgNVBAoTDERpZ2lDZXJ0IEluYzEZ
# MBcGA1UECxMQd3d3LmRpZ2ljZXJ0LmNvbTEhMB8GA1UEAxMYRGlnaUNlcnQgVHJ1
# c3RlZCBSb290IEc0MB4XDTIxMDQyOTAwMDAwMFoXDTM2MDQyODIzNTk1OVowaTEL
# MAkGA1UEBhMCVVMxFzAVBgNVBAoTDkRpZ2lDZXJ0LCBJbmMuMUEwPwYDVQQDEzhE
# aWdpQ2VydCBUcnVzdGVkIEc0IENvZGUgU2lnbmluZyBSU0E0MDk2IFNIQTM4NCAy
# MDIxIENBMTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBANW0L0LQKK14
# t13VOVkbsYhC9TOM6z2Bl3DFu8SFJjCfpI5o2Fz16zQkB+FLT9N4Q/QX1x7a+dLV
# ZxpSTw6hV/yImcGRzIEDPk1wJGSzjeIIfTR9TIBXEmtDmpnyxTsf8u/LR1oTpkyz
# ASAl8xDTi7L7CPCK4J0JwGWn+piASTWHPVEZ6JAheEUuoZ8s4RjCGszF7pNJcEIy
# j/vG6hzzZWiRok1MghFIUmjeEL0UV13oGBNlxX+yT4UsSKRWhDXW+S6cqgAV0Tf+
# GgaUwnzI6hsy5srC9KejAw50pa85tqtgEuPo1rn3MeHcreQYoNjBI0dHs6EPbqOr
# bZgGgxu3amct0r1EGpIQgY+wOwnXx5syWsL/amBUi0nBk+3htFzgb+sm+YzVsvk4
# EObqzpH1vtP7b5NhNFy8k0UogzYqZihfsHPOiyYlBrKD1Fz2FRlM7WLgXjPy6Ojs
# CqewAyuRsjZ5vvetCB51pmXMu+NIUPN3kRr+21CiRshhWJj1fAIWPIMorTmG7NS3
# DVPQ+EfmdTCN7DCTdhSmW0tddGFNPxKRdt6/WMtyEClB8NXFbSZ2aBFBE1ia3CYr
# AfSJTVnbeM+BSj5AR1/JgVBzhRAjIVlgimRUwcwhGug4GXxmHM14OEUwmU//Y09M
# u6oNCFNBfFg9R7P6tuyMMgkCzGw8DFYRAgMBAAGjggFZMIIBVTASBgNVHRMBAf8E
# CDAGAQH/AgEAMB0GA1UdDgQWBBRoN+Drtjv4XxGG+/5hewiIZfROQjAfBgNVHSME
# GDAWgBTs1+OC0nFdZEzfLmc/57qYrhwPTzAOBgNVHQ8BAf8EBAMCAYYwEwYDVR0l
# BAwwCgYIKwYBBQUHAwMwdwYIKwYBBQUHAQEEazBpMCQGCCsGAQUFBzABhhhodHRw
# Oi8vb2NzcC5kaWdpY2VydC5jb20wQQYIKwYBBQUHMAKGNWh0dHA6Ly9jYWNlcnRz
# LmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydFRydXN0ZWRSb290RzQuY3J0MEMGA1UdHwQ8
# MDowOKA2oDSGMmh0dHA6Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydFRydXN0
# ZWRSb290RzQuY3JsMBwGA1UdIAQVMBMwBwYFZ4EMAQMwCAYGZ4EMAQQBMA0GCSqG
# SIb3DQEBDAUAA4ICAQA6I0Q9jQh27o+8OpnTVuACGqX4SDTzLLbmdGb3lHKxAMqv
# bDAnExKekESfS/2eo3wm1Te8Ol1IbZXVP0n0J7sWgUVQ/Zy9toXgdn43ccsi91qq
# kM/1k2rj6yDR1VB5iJqKisG2vaFIGH7c2IAaERkYzWGZgVb2yeN258TkG19D+D6U
# /3Y5PZ7Umc9K3SjrXyahlVhI1Rr+1yc//ZDRdobdHLBgXPMNqO7giaG9OeE4Ttpu
# uzad++UhU1rDyulq8aI+20O4M8hPOBSSmfXdzlRt2V0CFB9AM3wD4pWywiF1c1LL
# RtjENByipUuNzW92NyyFPxrOJukYvpAHsEN/lYgggnDwzMrv/Sk1XB+JOFX3N4qL
# CaHLC+kxGv8uGVw5ceG+nKcKBtYmZ7eS5k5f3nqsSc8upHSSrds8pJyGH+PBVhsr
# I/+PteqIe3Br5qC6/To/RabE6BaRUotBwEiES5ZNq0RA443wFSjO7fEYVgcqLxDE
# DAhkPDOPriiMPMuPiAsNvzv0zh57ju+168u38HcT5ucoP6wSrqUvImxB+YJcFWbM
# bA7KxYbD9iYzDAdLoNMHAmpqQDBISzSoUSC7rRuFCOJZDW3KBVAr6kocnqX9oKcf
# BnTn8tZSkP2vhUgh+Vc7tJwD7YZF9LRhbr9o4iZghurIr6n+lB3nYxs6hlZ4TjCC
# B1QwggU8oAMCAQICEA3/+j8HRYAkaIkS75uyqoowDQYJKoZIhvcNAQELBQAwaTEL
# MAkGA1UEBhMCVVMxFzAVBgNVBAoTDkRpZ2lDZXJ0LCBJbmMuMUEwPwYDVQQDEzhE
# aWdpQ2VydCBUcnVzdGVkIEc0IENvZGUgU2lnbmluZyBSU0E0MDk2IFNIQTM4NCAy
# MDIxIENBMTAeFw0yMzAyMDkwMDAwMDBaFw0yNjAyMTAyMzU5NTlaMFkxCzAJBgNV
# BAYTAkRFMRowGAYDVQQHExFGcmFua2Z1cnQgYW0gTWFpbjEWMBQGA1UEChMNTWF0
# cml4NDIgR21iSDEWMBQGA1UEAxMNTWF0cml4NDIgR21iSDCCAiIwDQYJKoZIhvcN
# AQEBBQADggIPADCCAgoCggIBAKefDPqcNWCekj0megYTPI+xPig1LXiwMkF/bvAw
# QY5FEXAkh5qEfsImzev0RjUCAzhP3NepM72McpNYtQVAFo6Roo+D1IJLtgB6XhBX
# Wzcevp8UaHUYJNVRRgBK0j4zgzUnEAVco98ESM7XLsnD36cdCztXy6UHvQ3qGbBX
# pzSaNM6M6K9W/Fg5G50cadjdbKeQs7WONtHbH5DREbuRQk6kJrVtv2Lyv3hpieBe
# /2mCaLvtAL+qJhxBGIVG4JHyAiAKf3mhIjb2eJDfsvT8MXC9AAah+roVDoWOO4dG
# iNvmsDcfJ/fh4V/EzXBXM7mXEAY14lo+tkAq3MSjyOyZYDFX9LhvediBdzrPACBx
# 4NA4z4g01uibhbxb0mw6qVdLkgnXmCDG/qLLppI8kIteLtYHFferQlmWVcQc05wp
# /ntQNbs7uHB5LAK1SbeJaWSxmyofxpJhX6M+AL7IEOcJ02Ul+Q6yP9zXGKQ/Xh2n
# PUf1pmSnsbDdIMMZgjJsW6VnJDXGf0kqmA0Fv769fXy2qqZZhoK3miP+8L/weEK1
# 2gLwpXniCFLYXxS6QAP2Ft/UX97qqDNQRnex3DCrMnN4M8Kt6jjxVoIzBM+MfyOG
# qXul+5vBhOHGvrmMBtUy0WceH3YQtSPJyRE2GwzNgoXGdqYSyInm6YgIcI5EGOJX
# mfWJAgMBAAGjggIGMIICAjAfBgNVHSMEGDAWgBRoN+Drtjv4XxGG+/5hewiIZfRO
# QjAdBgNVHQ4EFgQUEisn9n8Ew9YAkyD9tX3/X0UEOHowDgYDVR0PAQH/BAQDAgeA
# MBMGA1UdJQQMMAoGCCsGAQUFBwMDMIG1BgNVHR8Ega0wgaowU6BRoE+GTWh0dHA6
# Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydFRydXN0ZWRHNENvZGVTaWduaW5n
# UlNBNDA5NlNIQTM4NDIwMjFDQTEuY3JsMFOgUaBPhk1odHRwOi8vY3JsNC5kaWdp
# Y2VydC5jb20vRGlnaUNlcnRUcnVzdGVkRzRDb2RlU2lnbmluZ1JTQTQwOTZTSEEz
# ODQyMDIxQ0ExLmNybDA+BgNVHSAENzA1MDMGBmeBDAEEATApMCcGCCsGAQUFBwIB
# FhtodHRwOi8vd3d3LmRpZ2ljZXJ0LmNvbS9DUFMwgZQGCCsGAQUFBwEBBIGHMIGE
# MCQGCCsGAQUFBzABhhhodHRwOi8vb2NzcC5kaWdpY2VydC5jb20wXAYIKwYBBQUH
# MAKGUGh0dHA6Ly9jYWNlcnRzLmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydFRydXN0ZWRH
# NENvZGVTaWduaW5nUlNBNDA5NlNIQTM4NDIwMjFDQTEuY3J0MAwGA1UdEwEB/wQC
# MAAwDQYJKoZIhvcNAQELBQADggIBACOCJbAxb/KttA2RnBs7KaWqs+0gLaaMonI0
# LjWieeYaqD7vJV8Fz5Df5fNZh64Keo/ajSGHOe41IaA22vGuuQczVnYMjoZ6U+jk
# ZVtY9EnS2oZwGa4ysXnRCcv3ZRMLU67s3/NsiZTx67yaDe8IwWDMARFw+tLhiCKm
# TD5F3rkkQ0urFzkOzAOkTtMTjJspe+4Wd11Lcq3qx5s8OPE5b+MN9gUacrmAkdR7
# XKPpQSpoYo0jkaXVpfXZoEMlzciH9unPxmGeWXBHJsgwEgd6thEHrpf/8iLlcT4Y
# qj6fJxotQe67PRe16S2taZgvyfrZqTe41LR+s8blj8W/heSZ42LmUIFFQ31zSuN1
# EPEgNnSii/hEvcGAnGMLZBNLUIIFh9D6zrvQxmfRykNxzJNM2LZ3PZ9ps57ll/kr
# HjfWfTmEEQA90zENyb8VflS0hrQ+uSBD00qrDo5/ueeyycuZyDMQ88vDI5F9893H
# sZ3p0Ub5sDMp5w9/kJMlm8RM7WS3ego1ZUhHc33OSh5jjWQl8PSRCa8x6w/Flrk7
# YGV+1X9FWBU5GZuFhJFGhp1DgkSVoeYxgwGUNgE5A0Z++gvJhgnuBj9xwSDFxBQc
# HrARWL/BDpRayntzEQHi0oTZ3FBzc7gxOl5WEffiQswhJz7B3Tuv36eY7bDd6x7H
# v031GgjGMYIG6TCCBuUCAQEwfTBpMQswCQYDVQQGEwJVUzEXMBUGA1UEChMORGln
# aUNlcnQsIEluYy4xQTA/BgNVBAMTOERpZ2lDZXJ0IFRydXN0ZWQgRzQgQ29kZSBT
# aWduaW5nIFJTQTQwOTYgU0hBMzg0IDIwMjEgQ0ExAhAN//o/B0WAJGiJEu+bsqqK
# MA0GCWCGSAFlAwQCAQUAoIHOMBkGCSqGSIb3DQEJAzEMBgorBgEEAYI3AgEEMBwG
# CisGAQQBgjcCAQsxDjAMBgorBgEEAYI3AgEVMC8GCSqGSIb3DQEJBDEiBCBBmOld
# SE8hB/5pp9t6bzTSERfe7kWxEUy1bLKpgvqRQjBiBgorBgEEAYI3AgEMMVQwUqA2
# gDQATQBhAHQAcgBpAHgANAAyACAAQwBsAGkAZQBuAHQAIABNAGEAbgBhAGcAZQBt
# AGUAbgB0oRiAFmh0dHA6Ly93d3cubWF0cml4NDIuZGUwDQYJKoZIhvcNAQEBBQAE
# ggIAJd6qUZVqpdtzvWV8YzOBGOgFRoYV9zXaqiNQygMF4lgFdLeqfzfRzT4Si8No
# jHpX9jmTTK0uiKmWTcEBrCP9FbR+oJzyl0Cu7CvVO3193RsFuY4beomM6DxSV3I+
# knp2fI5b1pG8yoIT63JKETXbaQ6mXD0PlS3oiq/NJRJsvyBVxsSsAw9mfZWpuwQR
# QyvripqooYQ6wcmeB5i3EtHPEKm5SSeHekxD9dhexKGlpEE4YcpcMXWMmoruyC87
# puSulW2Akuk18+2pm/q5XYXkV1c8Mzq4qtda46+LJ2EwfJAQw0c66pmp2eAoSMVr
# DYO7S3T4t2vvIrjqfEctSo5/ybSsKVtX7B3URskjBKCizW2NVuoZR6wZl+3YOUXN
# vdsJSseizDqqfh0Ec9AnHYBtSluIAAAtPYhH4/GKZSLS9QACMlqxj3gzLDEYJNCU
# lcPLe/0w7G4nfAmIUv3xfUSTmYCCK+lk9p9QX3X+hVBGyrDlH+ShyAb/BGaRUu8R
# YTRNNL3JwH+VFKTm/ruL8bT377RXg5ePHUDJ1NxRzk8/1C1YQ2ZNv9u/OfJF2gl1
# tKtS+9VhaSkTDu1w7CWxny24fP1ls8RPkPEmV+3jI6GTxKTGoGyI5nqiyiKtvXKr
# VrSL7Sq19Lk2Q4EphPLy3i0L0yGEn1cR2DcUbIsUakceqn+hggNsMIIDaAYJKoZI
# hvcNAQkGMYIDWTCCA1UCAQEwbzBbMQswCQYDVQQGEwJCRTEZMBcGA1UEChMQR2xv
# YmFsU2lnbiBudi1zYTExMC8GA1UEAxMoR2xvYmFsU2lnbiBUaW1lc3RhbXBpbmcg
# Q0EgLSBTSEEzODQgLSBHNAIQAUiQPcKKvKehGU0MHFe4KTALBglghkgBZQMEAgGg
# ggE9MBgGCSqGSIb3DQEJAzELBgkqhkiG9w0BBwEwHAYJKoZIhvcNAQkFMQ8XDTIz
# MDYwMjEzMjg1MFowKwYJKoZIhvcNAQk0MR4wHDALBglghkgBZQMEAgGhDQYJKoZI
# hvcNAQELBQAwLwYJKoZIhvcNAQkEMSIEIP1n8WNScdwB12MTQ2BX7obpU18vOY+U
# 3WrGCSlO25fTMIGkBgsqhkiG9w0BCRACDDGBlDCBkTCBjjCBiwQUMQMOF2qkWS6r
# LIut6DKZ/LVYXc8wczBfpF0wWzELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2Jh
# bFNpZ24gbnYtc2ExMTAvBgNVBAMTKEdsb2JhbFNpZ24gVGltZXN0YW1waW5nIENB
# IC0gU0hBMzg0IC0gRzQCEAFIkD3CirynoRlNDBxXuCkwDQYJKoZIhvcNAQELBQAE
# ggGApmZ2kEWt1JwGKVYeIC70L468Qu8czbWYOemu5ZcpsdJYDzPiDBPE5LFoA9im
# PBeUQwdJJIoI1Mpmgh5PoSKRSJ//y92DnVVNZfOfvN9PklZhu8/nKHMiZG9+3O5q
# cBC9YLJENRTn7E11sfn5HLQbOny4YYpFdHmDqPv/KJqxS88irRRd7rCc3a1Hivg8
# jHF/DKSxGTeVlkmAxO+tcmdy4m8wo9X5j1fTlgXdpu6dyZj2y/SLavGIz6kGK6To
# ojm7C1hFMRwY80cZxVJ7CwGSh2sy85y/Km1iIuitFPrkrmlYEJiEk54H6wrvbD4g
# pphdguTt43rYN6L3FKLRhTlxI/hc3/d7v0pg35SHr4HjDBiBv/gkI3sueWX0YngB
# HNXxRWe3azZApLXC+4RLYCyP4OPEavIGfDcBrSZEpfodXuUKKGYKKkgV2DTbMfMX
# DGz0LUWD36zMOU2QJWGzHIZ4Ty+G6EEVkIs/thCYSAidW6A8t2tILdKn9K+C9CXn
# NeQd
# SIG # End signature block
